@@ -12,7 +12,8 @@ class TestScanner(unittest.TestCase):
         paths = get_source_root_dirs(options, ["nope"])
         self.assertEqual(len(paths), 1)
         self.assertTrue(os.path.isabs(paths[0]))
-        self.assertEqual(paths[0], os.path.join(os.getcwd(), "foo"))
+        self.assertEqual(os.path.normcase(paths[0]),
+                         os.path.normcase(os.path.join(os.getcwd(), "foo")))
 
     def test_get_source_root_dirs_guess(self):
         options = optparse.Values({"sources_top_dirs": []})
@@ -20,7 +21,7 @@ class TestScanner(unittest.TestCase):
         paths = get_source_root_dirs(
             options, [os.path.join(cwd, "foo"), os.path.join(cwd, "bar")])
         self.assertEqual(len(paths), 1)
-        self.assertEqual(paths[0], cwd)
+        self.assertEqual(os.path.normcase(paths[0]), os.path.normcase(cwd))
 
         paths = get_source_root_dirs(options, [])
         self.assertEqual(paths, [])
